@@ -6,9 +6,6 @@ use LWP::UserAgent;
 use Test::TCP;
 use Plack::Loader;
 
-use parent qw(Exporter);
-our @EXPORT = qw( test_server );
-
 sub test_psgi {
     my %args = @_;
 
